@@ -162,6 +162,19 @@ export class Component {
     });
   }
 
+  /**
+   * Handles poll errors.
+   * @param {Error} err Error.
+   */
+  handlePollError(err) {
+    if (err) {
+      console.error(err);
+    }
+    if (this.poll.timer) {
+      clearInterval(this.poll.timer);
+    }
+  }
+
   /**
    * Sets up polling if it is defined on the component's root.
    */
@@ -186,6 +199,8 @@ export class Component {
         false
       );
 
+      // Call the method once before the timer starts
+      this.callMethod(this.poll.method, this.handlePollError);
       this.startPolling();
     }
   }
@@ -194,27 +209,26 @@ export class Component {
    * Starts polling and handles stopping the polling if there is an error.
    */
   startPolling() {
-    this.poll.timer = null;
-    const { timer } = this.poll;
+    this.poll.timer = setInterval(() => {
+      if (!this.poll.disable) {
+        if (hasValue(this.poll.disableData)) {
+          if (this.poll.disableData.startsWith("!")) {
+            // Manually negate this and re-negate it after the check
+            this.poll.disableData = this.poll.disableData.slice(1);
 
-    function handleError(err) {
-      if (err) {
-        console.error(err);
+            if (this.data[this.poll.disableData]) {
+              this.callMethod(this.poll.method, this.handlePollError);
+            }
+
+            this.poll.disableData = `!${this.poll.disableData}`;
+          } else if (!this.data[this.poll.disableData]) {
+            this.callMethod(this.poll.method, this.handlePollError);
+          }
+        } else {
+          this.callMethod(this.poll.method, this.handlePollError);
+        }
       }
-      if (timer) {
-        clearInterval(timer);
-      }
-    }
-
-    // Call the method once before the timer starts
-    this.callMethod(this.poll.method, handleError);
-
-    this.poll.timer = setInterval(
-      this.callMethod.bind(this),
-      this.poll.timing,
-      this.poll.method,
-      handleError
-    );
+    }, this.poll.timing);
   }
 
   /**
